@@ -11,7 +11,15 @@ DEFAULT_LOG_LEVEL = logging.INFO
 class Session():
     """Creates a Curia authentication session"""
 
-    def __init__(self, api_token: str = None, debug: bool = False):
+    def __init__(self, api_token: str = None, host: str = None, debug: bool = False):
+        """
+
+        Parameters
+        ----------
+        api_token: str :
+        host: str :
+        debug: bool :
+        """
         self.api_token = api_token
         self.debug = debug
         self.logger = setup_logger(name='curia', level=DEFAULT_LOG_LEVEL)
@@ -22,6 +30,8 @@ class Session():
 
         api_config = configuration.Configuration()
         api_config.debug = self.debug
-        api_config.access_token = self.api_token
+        api_config.api_key['Api-Key'] = self.api_token
+        if host:
+            api_config.host = host
 
-        self.api_instance = swagger_client.DefaultApi(swagger_client.ApiClient(api_config))
+        self.api_instance = swagger_client.PlatformApi(swagger_client.ApiClient(api_config))
